aboutsummaryrefslogtreecommitdiff
path: root/sys/firmware/acpi/acpi_madt.c
diff options
context:
space:
mode:
Diffstat (limited to 'sys/firmware/acpi/acpi_madt.c')
-rw-r--r--sys/firmware/acpi/acpi_madt.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/sys/firmware/acpi/acpi_madt.c b/sys/firmware/acpi/acpi_madt.c
index c23f2a4..119a842 100644
--- a/sys/firmware/acpi/acpi_madt.c
+++ b/sys/firmware/acpi/acpi_madt.c
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2023 Ian Marco Moffett and the VegaOS team.
+ * Copyright (c) 2023 Ian Marco Moffett and the Osmora Team.
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
@@ -10,7 +10,7 @@
* 2. Redistributions in binary form must reproduce the above copyright
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. Neither the name of VegaOS nor the names of its
* contributors may be used to endorse or promote products derived from
* this software without specific prior written permission.
*
@@ -40,7 +40,7 @@
#define APIC_TYPE_INTERRUPT_OVERRIDE 2
__MODULE_NAME("acpi");
-__KERNEL_META("$Vega$: acpi_madt.c, Ian Marco Moffett, "
+__KERNEL_META("$Hyra$: acpi_madt.c, Ian Marco Moffett, "
"ACPI MADT parsing");
static struct acpi_madt *madt = NULL;
@@ -10,7 +10,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
- * 3. Neither the name of VegaOS nor the names of its
+ * 3. Neither the name of Hyra nor the names of its
* contributors may be used to endorse or promote products derived from
* this software without specific prior written permission.